@@ -111,7 +111,7 @@ class SQLiteHandler(object):
                 tableobject = Table(tablename, column_names, column_types, records)
                 self.database.tables.update({tableobject.name: tableobject})
 
-    def table_create(self, tablename, recordname="", column_names=[], column_types=[], column_placements=[], defaults=[]):
+    def table_create(self, tablename, record_name="", column_names=[], column_types=[], column_placements=[], defaults=[]):
         """
         By default a table will have
         - ordering: to denote a desired order of the records, by default mirrors id column
